@@ -8,8 +8,3 @@ print.waitress <- function(x, ...) {
 
 	print(x, ...)
 }
-
-#' @export
-print.butler <- function(x, ...) {
-	print("A butler theme", ...)
-}
\ No newline at end of file
